@@ -1,4 +1,4 @@
-import ujson
+import json
 
 import marshmallow as ma
 from marshmallow.fields import (
@@ -20,8 +20,8 @@ lon = Number(
 lat = Number(
     required=True,
     validate=Range(
-        min=-180,
-        max=180,
+        min=-90,
+        max=90,
         error='Latitude must be between -90, 90'
     )
 )
@@ -30,4 +30,4 @@ lat = Number(
 class BaseSchema(ma.Schema):
 
     class Meta:
-        render_module = ujson
+        render_module = json
