@@ -1,5 +1,6 @@
-import marshmallow as ma
 from marshmallow.fields import (
+    Nested,
+    List,
     Str,
 )
 from marshmallow.validate import (
@@ -8,12 +9,20 @@ from marshmallow.validate import (
 from .object_type import (
     FEATURE_COLLECTION,
 )
+from ._base import BaseSchema
+from .feature import FeatureSchema
 
 
-class FeatureCollectionSchema(ma.Schema):
+class FeatureCollectionSchema(BaseSchema):
     type = Str(
         required=True,
         validate=OneOf(
             [FEATURE_COLLECTION],
-            error='Invalid feature collection type'),
+            error='Invalid feature collection type'
+        )
+    )
+
+    features = List(
+        Nested(FeatureSchema),
+        required=True,
     )
